// //////////////////////////////////////////////////////////////////////////
// Implementation file ConflictBlock.cpp for class ConflictBlock
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/06/17
// //////////////////////////////////////////////////////////////////////////

#include "StdAfx.h"
#include "ConflictBlock.h"


ConflictBlock::ConflictBlock( int nStartLineNumber ) :
    m_nStartLineNumber( nStartLineNumber ),
    m_nNumberOfLines( 0 )
{
}


ConflictBlock::~ConflictBlock()
{
}


int 
ConflictBlock::endLineNumber()
{
  if ( m_nNumberOfLines == 0 )
    return m_nStartLineNumber;
  return m_nStartLineNumber + m_nNumberOfLines -1;
}


bool 
ConflictBlock::operator ==( const ConflictBlock &other )
{
  return m_nStartLineNumber == other.m_nStartLineNumber  &&
         m_nNumberOfLines == other.m_nNumberOfLines;
}


bool 
ConflictBlock::operator <( const ConflictBlock &other )
{
  return m_nStartLineNumber < other.m_nStartLineNumber;
}


int 
ConflictBlock::lineStatus( int nLineIndex )
{
  if ( m_nNumberOfLines == 0 )
    return lineBeginConflictBlock;

  int nStatus = lineInsideConflictBlock;
  if ( m_nStartLineNumber == nLineIndex )
    nStatus |= lineBeginConflictBlock;
  if ( endLineNumber() == nLineIndex )
    nStatus |= lineEndConflictBlock;
  return nStatus;
}


bool 
ConflictBlock::isLineInside( int nLineIndex )
{
  return ( endLineNumber() >= nLineIndex  &&
           m_nStartLineNumber <= nLineIndex );
}


void 
ConflictBlock::increaseSizeBy( int nIncrement )
{
  m_nNumberOfLines += nIncrement;
  if ( m_nNumberOfLines < 0 )
    m_nNumberOfLines = 0;
}


void 
ConflictBlock::moveBlockBy( int nIncrement )
{
  m_nStartLineNumber += nIncrement;
  if ( m_nStartLineNumber < 0 )
    m_nStartLineNumber = 0;
}


void 
ConflictBlock::setLastLineNumber( int nLastLineNumber )
{
  m_nNumberOfLines = nLastLineNumber - m_nStartLineNumber +1;
  if ( m_nNumberOfLines < 0 )
    m_nNumberOfLines = 0;
}


void 
ConflictBlock::addLine( std::string line )
{
  m_lines.push_back( line );
  ++m_nNumberOfLines;
}


int 
ConflictBlock::startingLineNumber()
{
  return m_nStartLineNumber;
}


std::string 
ConflictBlock::conflictingTextLineAt( int nLineIndex )
{
  return m_lines.at( nLineIndex );
}


int 
ConflictBlock::numberOfLines()
{
  return m_nNumberOfLines;
}
