// //////////////////////////////////////////////////////////////////////////
// Header file ConflictBlock.h for class ConflictBlock
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/06/17
// //////////////////////////////////////////////////////////////////////////
#ifndef CONFLICTBLOCK_H
#define CONFLICTBLOCK_H

#include <string>
#include <vector>


/*! \class ConflictBlock
 * \brief This class represents a conflict block.
 */
class ConflictBlock
{
public:
  enum 
  {
    lineOutsideConflictBlock = 0,
    lineBeginConflictBlock = 1,
    lineInsideConflictBlock = 2,
    lineEndConflictBlock = 4,
    lineSelectedConflictBlock =8,
  };


  /*! Constructs a ConflictBlock object.
   */
  ConflictBlock( int nStartLineNumber );

  /*! Destructor.
   */
  virtual ~ConflictBlock();

  int endLineNumber();

  bool operator ==( const ConflictBlock &other );

  bool operator <( const ConflictBlock &other );

  int lineStatus( int nLineIndex );

  bool isLineInside( int nLineIndex );

  void increaseSizeBy( int nIncrement );

  void moveBlockBy( int nIncrement );

  void setLastLineNumber( int nLastLineNumber );

  void addLine( std::string line );

  std::string conflictingTextLineAt( int nLineIndex );

  int startingLineNumber();

  int numberOfLines();

private:
  int m_nStartLineNumber;
  int m_nNumberOfLines;
  std::vector<std::string> m_lines;
};



// Inlines methods for ConflictBlock:
// ----------------------------------



#endif  // CONFLICTBLOCK_H
