// //////////////////////////////////////////////////////////////////////////
// Header file ConflictFileLoader.h for class ConflictFileLoader
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/06/16
// //////////////////////////////////////////////////////////////////////////
#ifndef CONFLICTFILELOADER_H
#define CONFLICTFILELOADER_H

#include "ConflictTextBuilder.h"
#include <string>
class LineReader;


/*! \class ConflictFileLoader
 * \brief This class load a conflict file.
 */
class ConflictFileLoader
{
public:
  /*! Constructs a ConflictFileLoader object.
   */
  ConflictFileLoader( CString fileName, 
                      ConflictTextBuilder *pTargetBuffer,
                      ConflictTextBuilder *pMergedBuffer );

  /*! Destructor.
   */
  virtual ~ConflictFileLoader();

  bool loadFile();

  std::string mergedRevision();

private:
  /// Prevents the use of the copy constructor.
  ConflictFileLoader( const ConflictFileLoader &copy );

  /// Prevents the use of the copy operator.
  void operator =( const ConflictFileLoader &copy );

  void readLines( LineReader *lineReader );

  void appendLineToTextBuffers( std::string line );

  void readConflictBlock( std::string headLine,
                          LineReader *lineReader );

  bool isLineStartingConflictBlock( std::string line );

  void readTargetLines( LineReader *lineReader );
  void readMergedLines( LineReader *lineReader );

  void extractMergedRevision( int nLimiterPos, 
                              std::string line );

private:
  ConflictTextBuilder *m_pTargetBuffer;
  ConflictTextBuilder *m_pMergedBuffer;
  CString m_fileName;
  std::string m_mergedRevision;

  static std::string ms_conflictLimiter;
  static std::string ms_conflictSeparator;
};



// Inlines methods for ConflictFileLoader:
// ---------------------------------------



#endif  // CONFLICTFILELOADER_H
