// //////////////////////////////////////////////////////////////////////////
// Implementation file ConflictMarginDrawer.cpp for class ConflictMarginDrawer
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/06/17
// //////////////////////////////////////////////////////////////////////////

#include "StdAfx.h"
#include "ConflictBlock.h"
#include "ConflictList.h"
#include "ConflictMarginDrawer.h"
#include "ConflictTextBuffer.h"


ConflictMarginDrawer::ConflictMarginDrawer() :
  m_conflictBlockLimitWidth( 10 ),
  m_conflictBlockLimitHeight( 3 ),
  m_conflictBlockMarkWidth( 5 ),
  m_conflictBlockRightMargin( 3 ),
  m_conflictBlockLeftBorderOffset( m_conflictBlockLimitWidth + 
                                   m_conflictBlockRightMargin )
{
}


ConflictMarginDrawer::~ConflictMarginDrawer()
{
}


void 
ConflictMarginDrawer::DrawMargin( CDC * pDc, 
                                  const CRect &rect, 
                                  int nLineIndex,
                                  ConflictTextBuffer *pTextBuffer,
                                  int nCurrentConflictIndex )
{
  int nLineStatus = 
      pTextBuffer->conflicts()->conflictBlockStatusFor( nLineIndex,
                                                        nCurrentConflictIndex );
  if ( nLineStatus == 0 )
    return;

  COLORREF blockColor = conflictBlockColorFor( nLineStatus );

  if ( ( nLineStatus & ConflictBlock::lineInsideConflictBlock) != 0 )
    drawInsideConflictBlockMark( pDc, rect, blockColor );
  if ( ( nLineStatus & ConflictBlock::lineBeginConflictBlock) != 0 )
    drawBeginConflictBlockMark( pDc, rect, blockColor );
  if ( ( nLineStatus & ConflictBlock::lineEndConflictBlock) != 0 )
    drawEndConflictBlockMark( pDc, rect, blockColor );
}


void 
ConflictMarginDrawer::drawInsideConflictBlockMark( CDC *pDc, 
                                                   const CRect &rect, 
                                                   COLORREF blockColor )
{
  CPoint markPosition( rect.right-m_conflictBlockLeftBorderOffset, rect.top );
  CSize markSize( m_conflictBlockMarkWidth, rect.Height() );
  CRect markRect( markPosition, markSize );
  pDc->FillSolidRect( markRect, blockColor );
}


void 
ConflictMarginDrawer::drawBeginConflictBlockMark( CDC *pDc, 
                                                  const CRect &rect, 
                                                  COLORREF blockColor )
{
  CPoint markPosition( rect.right-m_conflictBlockLeftBorderOffset, rect.top );
  CSize markSize( m_conflictBlockLimitWidth, m_conflictBlockLimitHeight );
  CRect markRect( markPosition, markSize );
  pDc->FillSolidRect( markRect, blockColor );
}


void 
ConflictMarginDrawer::drawEndConflictBlockMark( CDC *pDc, 
                                                const CRect &rect, 
                                                COLORREF blockColor )
{
  CPoint markPosition( rect.right-m_conflictBlockLeftBorderOffset, 
                       rect.bottom-m_conflictBlockLimitHeight );
  CSize markSize( m_conflictBlockLimitWidth, m_conflictBlockLimitHeight );
  CRect markRect( markPosition, markSize );
  pDc->FillSolidRect( markRect, blockColor );
}


COLORREF 
ConflictMarginDrawer::conflictBlockColorFor( int nLineStatus )
{
  if ( ( nLineStatus & ConflictBlock::lineSelectedConflictBlock) != 0 )
    return selectedConflictBlockColor();
  return conflictBlockColor();
}


COLORREF 
ConflictMarginDrawer::selectedConflictBlockColor()
{
  return RGB( 192,192, 0 );
}


COLORREF 
ConflictMarginDrawer::conflictBlockColor()
{
  return RGB( 192,0,0 );
}
