// //////////////////////////////////////////////////////////////////////////
// Header file MultiFileDropList.h for class MultiFileDropList
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/06/17
// //////////////////////////////////////////////////////////////////////////
#if !defined(AFX_MULTIFILEDROPLIST_H__4CB59AC1_903E_11D1_91CF_B32000EA6861__INCLUDED_)
#define AFX_MULTIFILEDROPLIST_H__4CB59AC1_903E_11D1_91CF_B32000EA6861__INCLUDED_

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000



#include <vector>


/*! This class provides multiple files drop support to an application.

  Here is a typical usage (add a WM_DROPFILES handler to CMainFrame). 
  It opens each dropped files.

  \code
  void CMainFrame::OnDropFiles(HDROP hDropInfo) 
  {
    MultiFileDropList fileList( hDropInfo );
    fileList.OpenDocuments( &theApp );
  }
  \endcode
*/
class MultiFileDropList
{
public:
  /*! Constructs the list of dropped file from the specified drop source.
   * \param hDrop Drop source the dropped file list is build from.
   */
  MultiFileDropList( HDROP hDrop );

  virtual ~MultiFileDropList();

  /*! Opens each dropped document.
   * 
   * Document are opened using CWinApp::OpenDocument().
   */
	void openDocuments();

protected:
  CString dropSourceFileNameAt( HDROP hDrop, int nFileIndex );

  typedef std::vector<CString> DroppedFiles;
  DroppedFiles m_droppedFiles;
};


#endif // !defined(AFX_MULTIFILEDROPLIST_H__4CB59AC1_903E_11D1_91CF_B32000EA6861__INCLUDED_)
